@@ -1064,10 +1064,10 @@ def parse_record(record: neo4j.data.Record, flag=True):
                         _record["relationship"].append(relationship2dict(x))
                     elif issubclass(x.__class__, neo4j.graph.Relationship):
                         _record["relationship"].append(relationship2dict(x))
-                    elif isinstance(rd, neo4j.graph.Path):
-                        _record["path"].append(path2dict(rd))
+                    elif isinstance(x, neo4j.graph.Path):
+                        _record["path"].append(path2dict(x))
                     else:
-                        _record["other"].append(rd)
+                        _record["other"].append(x)
             elif isinstance(rd, neo4j.graph.Path):
                 _record["path"].append(path2dict(rd))
             else:
